@@ -1,3 +1,4 @@
+import contextlib
 import datetime
 import logging
 import os
@@ -69,7 +70,7 @@ class AWSAthenaAdapter(Adapter):
         aws_account_id = sts.get_caller_identity()['Account']
         output_s3_bucket = f'aws-athena-query-results-{aws_account_id}-{aws_region}'
 
-        logger.debug(f'Querying.. aws_region={aws_region}, catalog={catalog}, output_s3_bucket={output_s3_bucket}')
+        logger.debug(f'Querying.. aws_region={aws_region}, catalog={catalog}, output_s3_bucket={output_s3_bucket}.')
         query_execution_context = {'Catalog': catalog}
         if database:
             query_execution_context['Database'] = database
@@ -108,10 +109,8 @@ class AWSAthenaAdapter(Adapter):
                 s3.download_file(output_s3_bucket, output_s3_key, local_filename)
                 df = CSVAdapter.load(f'csv://{local_filename}', None)
             finally:
-                try:
+                with contextlib.suppress(FileNotFoundError):
                     os.remove(local_filename)
-                except FileNotFoundError:
-                    pass
             return df
 
     @staticmethod
@@ -134,7 +133,7 @@ class AWSAthenaAdapter(Adapter):
             if isinstance(json_schema['type'], str):
                 json_types = {json_schema['type']}
             else:
-                assert(isinstance(json_schema['type'], list))
+                assert (isinstance(json_schema['type'], list))
                 json_types = json_schema['type']
             for json_type in json_types:
                 if json_type == 'array':
@@ -154,7 +153,7 @@ class AWSAthenaAdapter(Adapter):
                         'object': 'string',
                     }[json_type])
         else:
-            assert('anyOf' in json_schema)
+            assert ('anyOf' in json_schema)
             for sub_definition in json_schema['anyOf']:
                 presto_types.add(AWSAthenaAdapter.resolve_presto_type(sub_definition))
         if 'null' in presto_types and presto_types != {'null'}:
@@ -165,7 +164,7 @@ class AWSAthenaAdapter(Adapter):
         if len(presto_types) > 1:
             if top_level:
                 logger.warning(f'Identified multiple conflicting types for {column_name}: {presto_types}. Picking one '
-                               'arbitrarily.')
+                               + 'arbitrarily.')
             presto_types = {presto_types.pop()}
         if len(presto_types) == 0:
             if top_level:
@@ -261,7 +260,7 @@ class AWSAthenaAdapter(Adapter):
                         existing_prefix = existing_uri.path.strip('/')
                         if existing_bucket != s3_bucket:
                             raise AppendSchemeConflictError('Cannot append to existing table - s3 bucket mismatch '
-                                                            f'(pre-existing location is {pre_existing_s3_base_url})')
+                                                            + f'(pre-existing location is {pre_existing_s3_base_url})')
                         if existing_prefix.startswith(s3_bucket_prefix):
                             # Discovered prefix is more restrictive than our requested prefix - this is safe, we can
                             # just adopt it.
@@ -275,9 +274,8 @@ class AWSAthenaAdapter(Adapter):
                     schema_ddl, _ = AWSAthenaAdapter._gen_schema(df, data_format, table_name, s3_base_url)
                     logger.warning(
                         f'Deleting table definition for {database}.{table_name}. Leaving old data behind and changing '
-                        'prefix to {s3_bucket_prefix}/.')
+                        + f'prefix to {s3_bucket_prefix}/.')
                     assert s3_base_url and schema_ddl and s3_bucket_prefix  # safety check
-                    # time.sleep(5)  # give user time to abort if running from CLI
                     old_table_schema_query_result = AWSAthenaAdapter._run_athena_query(
                         query=f'SHOW CREATE TABLE `{table_name}`', return_results_raw=True,
                         aws_region=aws_region, catalog='AwsDataCatalog', database=database, athena_client=athena_client
