@@ -18,18 +18,20 @@ class AWSDynamoDB(Adapter):
     @staticmethod
     def load(uri, query):
         import boto3
-
         uri = parse_uri(uri)
         aws_region = uri.authority
         table_name = uri.path.strip('/')
 
         dynamodb = boto3.client('dynamodb', region_name=aws_region)
 
-        scan_results = dynamodb.get_paginator('scan').paginate(TableName=table_name)
-        raw_array = []
-
-        logger.info('Sequentially querying DynamoDB scan results...')
-        for response in scan_results:
-            raw_array.extend(response['Items'])
+        if query:
+            result = dynamodb.execute_statement(Statement=query)
+            raw_array = result['Items']
+        else:
+            logger.info('Sequentially querying DynamoDB scan results...')
+            scan_results = dynamodb.get_paginator('scan').paginate(TableName=table_name)
+            raw_array = []
+            for response in scan_results:
+                raw_array.extend(response['Items'])
 
         return pd.DataFrame.from_records(raw_array)
