@@ -185,7 +185,10 @@ def validate_coercion_schema(schema: Dict[str, str]) -> None:
     SCHEMA_COERCION_SUPPORTED_TYPES = {'datetime', 'str', 'int', 'float'}
     unsupported_schema_types = set(schema.values()) - SCHEMA_COERCION_SUPPORTED_TYPES
     if unsupported_schema_types:
-        raise ValueError(f'Unsupported schema type(s): {", ".join(unsupported_schema_types)}')
+        raise ValueError(
+            f'Unsupported schema type(s): {", ".join((str(item) for item in unsupported_schema_types))}. '
+            + f'Please specify one of the supported types: {", ".join(SCHEMA_COERCION_SUPPORTED_TYPES)}.'
+        )
 
 
 def coerce_schema(df: pd.DataFrame, schema: Dict[str, str], restrict_schema: bool) -> pd.DataFrame:
@@ -199,8 +202,16 @@ def coerce_schema(df: pd.DataFrame, schema: Dict[str, str], restrict_schema: boo
     for col in set(schema.keys()).intersection(set(df.columns)):
         try:
             if schema[col] == 'datetime':
+                def coerce_datetime(item):
+                    if item in (None, ''):
+                        return None
+                    if isinstance(item, str):
+                        return ciso8601.parse_datetime(item)
+                    if isinstance(item, pd.Timestamp):
+                        return item.to_pydatetime()
+                    raise TypeError(item)
                 df[col] = df.apply(
-                    lambda r: ciso8601.parse_datetime(r[col]) if r[col] not in (None, '') else None, axis=1
+                    lambda r: coerce_datetime(r[col]), axis=1
                 )
             elif schema[col] == 'str':
                 df[col] = df[col].astype('string')
@@ -263,7 +274,7 @@ def load_url(url: Union[str, Path], params: Optional[Dict[str, Any]] = None, que
          :ref:Adapters documentation for details.
     :param query:
         To extract only some of the data, provide a query here, to run on the data. This will need to be written in the
-        native query language of whatever ddata format you are extracting data from (e.g. SQL for a SQL database), or
+        native query language of whatever data format you are extracting data from (e.g. SQL for a SQL database), or
         for formats without a native query language (e.g. CSV), the DuckDB SQL syntax is normally supported. Refer to
         the :ref:Adapters documentation for details.
     :param fiter_sql:
@@ -271,9 +282,9 @@ def load_url(url: Union[str, Path], params: Optional[Dict[str, Any]] = None, que
         Transformations are powered by DuckDB and uses the DuckDB SQL syntax. Reference the table named ``data`` for
         the raw imported data.
     :param schema_coercion:
-        This is an experimental feature. Subject to change. Docummentation unavailable.
+        This is an experimental feature. Subject to change. Documentation unavailable.
     :param restrict_schema:
-        This is an experimental feature. Subject to change. Docummentation unavailable.
+        This is an experimental feature. Subject to change. Documentation unavailable.
 
     :raises tableconv.InvalidURLError:
         Raised if the provided URL cannot be accessed. (anything from an unsupported/unrecognized data format, an
@@ -322,7 +333,7 @@ def load_url(url: Union[str, Path], params: Optional[Dict[str, Any]] = None, que
     # Run in-memory filters
     if filter_sql:
         logger.debug('Running intermediate filter sql query in-memory')
-        df = query_in_memory(df, filter_sql)
+        df = query_in_memory([('data', df)], filter_sql)
 
     if df.empty:
         raise EmptyDataError('No rows returned by intermediate filter sql query')
